@@ -1,9 +1,32 @@
-""""""
-
-from typing import Callable, Dict, List
-import pytz
+from typing import Dict, List
 from datetime import datetime
 from time import sleep
+from pathlib import Path
+
+from vnpy.event import EventEngine
+from vnpy.trader.constant import (
+    Direction,
+    Exchange,
+    Offset,
+    OptionType,
+    OrderType,
+    Status,
+    Product
+)
+from vnpy.trader.gateway import BaseGateway
+from vnpy.trader.object import (
+    AccountData,
+    CancelRequest,
+    ContractData,
+    OrderData,
+    OrderRequest,
+    PositionData,
+    SubscribeRequest,
+    TickData,
+    TradeData,
+)
+from vnpy.trader.utility import get_folder_path, ZoneInfo
+from vnpy.trader.event import EVENT_TIMER
 
 from ..api import (
     MdApi,
@@ -33,33 +56,10 @@ from ..api import (
     USTP_FTDC_VC_AV,
     USTP_FTDC_VC_CV
 )
-from vnpy.event.engine import EventEngine
-from vnpy.trader.constant import (
-    Direction,
-    Exchange,
-    Offset,
-    OptionType,
-    OrderType,
-    Status,
-    Product
-)
-from vnpy.trader.event import EVENT_TIMER
-from vnpy.trader.gateway import BaseGateway
-from vnpy.trader.object import (
-    AccountData,
-    CancelRequest,
-    ContractData,
-    OrderData,
-    OrderRequest,
-    PositionData,
-    SubscribeRequest,
-    TickData,
-    TradeData,
-)
-from vnpy.trader.utility import get_folder_path
 
 
-STATUS_FEMAS2VT = {
+# 委托状态映射
+STATUS_FEMAS2VT: Dict[str, Status] = {
     USTP_FTDC_CAS_Submitted: Status.SUBMITTING,
     USTP_FTDC_CAS_Accepted: Status.SUBMITTING,
     USTP_FTDC_CAS_Rejected: Status.REJECTED,
@@ -69,26 +69,30 @@ STATUS_FEMAS2VT = {
     USTP_FTDC_OS_Canceled: Status.CANCELLED,
 }
 
-DIRECTION_VT2FEMAS = {
+# 多空方向映射
+DIRECTION_VT2FEMAS: Dict[Direction, str] = {
     Direction.LONG: USTP_FTDC_D_Buy,
     Direction.SHORT: USTP_FTDC_D_Sell,
 }
-DIRECTION_FEMAS2VT = {v: k for k, v in DIRECTION_VT2FEMAS.items()}
+DIRECTION_FEMAS2VT: Dict[str, Direction] = {v: k for k, v in DIRECTION_VT2FEMAS.items()}
 
-ORDERTYPE_VT2FEMAS = {
+# 委托类型映射
+ORDERTYPE_VT2FEMAS: Dict[OrderType, str] = {
     OrderType.LIMIT: USTP_FTDC_OPT_LimitPrice,
     OrderType.MARKET: USTP_FTDC_OPT_AnyPrice,
 }
 
-OFFSET_VT2FEMAS = {
+# 开平方向映射
+OFFSET_VT2FEMAS: Dict[Offset, str] = {
     Offset.OPEN: USTP_FTDC_OF_Open,
     Offset.CLOSE: USTP_FTDC_OF_Close,
     Offset.CLOSETODAY: USTP_FTDC_OF_CloseYesterday,
     Offset.CLOSEYESTERDAY: USTP_FTDC_OF_CloseToday,
 }
-OFFSET_FEMAS2VT = {v: k for k, v in OFFSET_VT2FEMAS.items()}
+OFFSET_FEMAS2VT: Dict[str, Offset] = {v: k for k, v in OFFSET_VT2FEMAS.items()}
 
-EXCHANGE_FEMAS2VT = {
+# 交易所映射
+EXCHANGE_FEMAS2VT: Dict[str, Exchange] = {
     "CFFEX": Exchange.CFFEX,
     "SHFE": Exchange.SHFE,
     "CZCE": Exchange.CZCE,
@@ -96,20 +100,22 @@ EXCHANGE_FEMAS2VT = {
     "INE": Exchange.INE,
 }
 
-OPTIONTYPE_FEMAS2VT = {
+# 期权类型映射
+OPTIONTYPE_FEMAS2VT: Dict[str, OptionType] = {
     USTP_FTDC_OT_CallOptions: OptionType.CALL,
     USTP_FTDC_OT_PutOptions: OptionType.PUT,
 }
 
-CHINA_TZ = pytz.timezone("Asia/Shanghai")
-
+# 其他常量
+CHINA_TZ = ZoneInfo("Asia/Shanghai")       # 中国时区
 
+# 合约数据全局缓存字典
 symbol_contract_map: Dict[str, ContractData] = {}
 
 
 class FemasGateway(BaseGateway):
     """
-    VeighNa用于连接飞马柜台的接口
+    VeighNa用于连接飞马柜台的接口。
     """
 
     default_name: str = "FEMAS"
@@ -130,8 +136,8 @@ class FemasGateway(BaseGateway):
         """构造函数"""
         super().__init__(event_engine, gateway_name)
 
-        self.td_api: FemasTdApi = FemasTdApi(self)
-        self.md_api: FemasTdApi = FemasMdApi(self)
+        self.td_api: "FemasTdApi" = FemasTdApi(self)
+        self.md_api: "FemasTdApi" = FemasMdApi(self)
 
     def connect(self, setting: dict) -> None:
         """连接交易接口"""
@@ -148,7 +154,6 @@ class FemasGateway(BaseGateway):
 
         appid: str = setting["产品名称"]
         auth_code: str = setting["授权编码"]
-        
 
         self.td_api.connect(td_address, userid, password, brokerid, auth_code, appid)
         self.md_api.connect(md_address, userid, password, brokerid)
@@ -194,14 +199,14 @@ class FemasGateway(BaseGateway):
             return
         self.count = 0
 
-        func: Callable = self.query_functions.pop(0)
+        func = self.query_functions.pop(0)
         func()
         self.query_functions.append(func)
 
     def init_query(self) -> None:
         """初始化查询任务"""
         self.count: int = 0
-        self.query_functions: List[Callable] = [self.query_account, self.query_position]
+        self.query_functions: list = [self.query_account, self.query_position]
         self.event_engine.register(EVENT_TIMER, self.process_timer_event)
 
 
@@ -210,7 +215,7 @@ class FemasMdApi(MdApi):
 
     def __init__(self, gateway: FemasGateway) -> None:
         """构造函数"""
-        super(FemasMdApi, self).__init__()
+        super().__init__()
 
         self.gateway: FemasGateway = gateway
         self.gateway_name: str = gateway.gateway_name
@@ -222,7 +227,7 @@ class FemasMdApi(MdApi):
         self.auth_staus: bool = False
         self.login_failed: bool = False
 
-        self.subscribed: List[str] = set()
+        self.subscribed: set = set()
 
         self.userid: str = ""
         self.password: str = ""
@@ -269,7 +274,7 @@ class FemasMdApi(MdApi):
 
         timestamp: str = f"{data['TradingDay']} {data['UpdateTime']}.{int(data['UpdateMillisec'] / 100)}"
         dt: datetime = datetime.strptime(timestamp, "%Y%m%d %H:%M:%S.%f")
-        dt = CHINA_TZ.localize(dt)
+        dt: datetime = dt.replace(tzinfo=CHINA_TZ)
 
         tick: TickData = TickData(
             symbol=symbol,
@@ -300,7 +305,7 @@ class FemasMdApi(MdApi):
 
         # 禁止重复发起连接，会导致异常崩溃
         if not self.connect_status:
-            path = get_folder_path(self.gateway_name.lower())
+            path: Path = get_folder_path(self.gateway_name.lower())
             self.createFtdcMdApi((str(path) + "\\Md").encode("GBK"))
 
             self.subscribeMarketDataTopic(100, 2)
@@ -340,7 +345,7 @@ class FemasTdApi(TdApi):
 
     def __init__(self, gateway: FemasGateway):
         """构造函数"""
-        super(FemasTdApi, self).__init__()
+        super().__init__()
 
         self.gateway: FemasGateway = gateway
         self.gateway_name: str = gateway.gateway_name
@@ -359,10 +364,9 @@ class FemasTdApi(TdApi):
         self.brokerid: int = 0
         self.auth_code: str = ""
         self.appid: str = ""
-        
 
-        self.positions: dict = {}
-        self.tradeids: List[str] = set()
+        self.positions: Dict[str, PositionData] = {}
+        self.tradeids: set = set()
 
     def onFrontConnected(self) -> None:
         """服务器连接成功回报"""
@@ -416,7 +420,7 @@ class FemasTdApi(TdApi):
         if not error["ErrorID"]:
             return
 
-        orderid:str = data["UserOrderLocalID"]
+        orderid: str = data["UserOrderLocalID"]
         symbol: str = data["InstrumentID"]
         contract: ContractData = symbol_contract_map[symbol]
 
@@ -442,10 +446,6 @@ class FemasTdApi(TdApi):
 
         self.gateway.write_error("交易撤单失败", error)
 
-    def onRspQueryMaxOrderVolume(self, data: dict, error: dict, reqid: int, last: bool) -> None:
-        """"""
-        pass
-
     def onRspSettlementInfoConfirm(
         self, data: dict, error: dict, reqid: int, last: bool
     ) -> None:
@@ -511,7 +511,7 @@ class FemasTdApi(TdApi):
 
     def onRspQryInstrument(self, data: dict, error: dict, reqid: int, last: bool) -> None:
         """合约查询回报"""
-        # 飞马柜台没有提供ProductClass数据，因此需要使用以下逻辑确定产品类型。  
+        # 飞马柜台没有提供ProductClass数据，因此需要使用以下逻辑确定产品类型。
         option_type: OptionType = OPTIONTYPE_FEMAS2VT.get(data["OptionsType"], None)
         if option_type:
             product = Product.OPTION
@@ -554,7 +554,7 @@ class FemasTdApi(TdApi):
         """委托更新推送"""
         timestamp: str = f"{data['InsertDate']} {data['InsertTime']}"
         dt: datetime = datetime.strptime(timestamp, "%Y%m%d %H:%M:%S")
-        dt = CHINA_TZ.localize(dt)
+        dt: datetime = dt.replace(tzinfo=CHINA_TZ)
 
         order: OrderData = OrderData(
             symbol=data["InstrumentID"],
@@ -583,7 +583,7 @@ class FemasTdApi(TdApi):
 
         timestamp: str = f"{data['TradeDate']} {data['TradeTime']}"
         dt: datetime = datetime.strptime(timestamp, "%Y%m%d %H:%M:%S")
-        dt = CHINA_TZ.localize(dt)
+        dt: datetime = dt.replace(tzinfo=CHINA_TZ)
 
         trade: OrderData = TradeData(
             symbol=data["InstrumentID"],
@@ -608,7 +608,6 @@ class FemasTdApi(TdApi):
         brokerid: int,
         auth_code: str,
         appid: str,
-  
     ) -> None:
         """连接服务器"""
         self.userid = userid
@@ -617,10 +616,9 @@ class FemasTdApi(TdApi):
         self.address = address
         self.auth_code = auth_code
         self.appid = appid
-        
 
         if not self.connect_status:
-            path = get_folder_path(self.gateway_name.lower())
+            path: Path = get_folder_path(self.gateway_name.lower())
             self.createFtdcTraderApi(str(path) + "\\Td")
 
             self.subscribePrivateTopic(0)
@@ -642,8 +640,6 @@ class FemasTdApi(TdApi):
             "EncryptType": "1",
         }
 
-        
-
         self.reqid += 1
         self.reqDSUserCertification(req, self.reqid)
 
@@ -659,8 +655,6 @@ class FemasTdApi(TdApi):
             "AppID": self.appid
         }
 
-        
-
         self.reqid += 1
         self.reqUserLogin(req, self.reqid)
 
@@ -668,7 +662,7 @@ class FemasTdApi(TdApi):
         """委托查询可用投资者"""
         self.reqid += 1
 
-        req = {
+        req: dict = {
             "BrokerID": self.brokerid,
             "UserID": self.userid,
         }
